@@ -1,19 +1,20 @@
 """Module providing interactive widgets to select and display log data from the *CARWatch App*."""
 from __future__ import annotations
-from pathlib import Path
-from typing import TYPE_CHECKING, Optional, Union, Callable, Tuple, List
 
 import re
-from typing_extensions import Literal, get_args
+from pathlib import Path
+from typing import TYPE_CHECKING, Callable, List, Optional, Tuple, Union
 
 import pandas as pd
+from typing_extensions import Literal, get_args
 
 from biopsykit.utils._types import path_t
-from biopsykit.carwatch_logs import LogData
 
 if TYPE_CHECKING:
     import ipywidgets.widgets
 
+    from biopsykit.carwatch_logs import LogData
+
 LOG_FILENAME_PATTERN = "logs_(.*?)"
 
 INPUT_TYPES = Literal["file", "folder"]
@@ -102,7 +103,7 @@ def _log_file_subject_dropdown_get_option_list(subject_list: List[str], log_file
 
 
 def action_dropdown_widget(
-    data: Union[LogData, pd.DataFrame], callback: Optional[Callable] = None
+    data: Union["LogData", pd.DataFrame], callback: Optional[Callable] = None
 ) -> "ipywidgets.Dropdown":
     """Create dropdown widget to filter log data by a specific action.
 
@@ -119,6 +120,8 @@ def action_dropdown_widget(
         dropdown widget
 
     """
+    from biopsykit.carwatch_logs import LogData  # pylint:disable=import-outside-toplevel
+
     try:
         import ipywidgets.widgets  # pylint:disable=import-outside-toplevel
     except ImportError as e:
@@ -141,7 +144,7 @@ def action_dropdown_widget(
 
 
 def day_dropdown_widget(
-    data: Union[LogData, pd.DataFrame], callback: Optional[Callable] = None
+    data: Union["LogData", pd.DataFrame], callback: Optional[Callable] = None
 ) -> "ipywidgets.Dropdown":
     """Create dropdown widget to filter log data by a specific day.
 
@@ -158,6 +161,8 @@ def day_dropdown_widget(
         dropdown widget
 
     """
+    from biopsykit.carwatch_logs import LogData  # pylint:disable=import-outside-toplevel
+
     try:
         import ipywidgets.widgets  # pylint:disable=import-outside-toplevel
     except ImportError as e:
