@@ -8,8 +8,8 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import seaborn as sns
+from fau_colors import colors_all
 
-from biopsykit import colors
 from biopsykit.protocols import BaseProtocol
 from biopsykit.signals.ecg.plotting import hr_plot
 from biopsykit.utils.exceptions import FeatureComputationError
@@ -474,7 +474,7 @@ class CFT(BaseProtocol):
 
         # get time points in seconds
         # TODO check index type
-        idx_s = df_hr_cft.index.view(int) / 1e9
+        idx_s = df_hr_cft.index.view(np.int64) / 1e9
         idx_s = idx_s - idx_s[0]
 
         # apply a 2nd degree polynomial fit
@@ -597,7 +597,7 @@ class CFT(BaseProtocol):
         cft_params = self.compute_cft_parameter(data, return_dict=True)
 
         if not kwargs.get("plot_datetime_index", False):
-            data.index = (data.index - data.index[0]).view(int) / 1e9
+            data.index = (data.index - data.index[0]).view(np.int64) / 1e9
 
         times_dict = self._cft_plot_get_cft_times(data, time_baseline, time_recovery)
         df_plot = self._cft_plot_extract_plot_interval(data, times_dict)
@@ -690,7 +690,7 @@ class CFT(BaseProtocol):
                 y=0.95,
                 transform=ax.get_xaxis_transform(),
                 s=name,
-                # bbox=bbox,
+                zorder=3,
                 ha="center",
                 va="center",
             )
@@ -700,7 +700,7 @@ class CFT(BaseProtocol):
             height=0.1,
             color="white",
             alpha=0.4,
-            zorder=3,
+            zorder=1,
             lw=0,
             transform=ax.transAxes,
         )
@@ -741,8 +741,8 @@ class CFT(BaseProtocol):
         max_hr_cft = float(self.extract_cft_interval(data).max())
         cft_start = cft_times["cft_start"]
 
-        color = colors.fau_color(color_key)
-        color_adjust = colors.adjust_color(color_key, 1.5)
+        color = getattr(colors_all, color_key)
+        color_adjust = getattr(colors_all, f"{color_key}_dark")
 
         # Peak Bradycardia vline
         ax.axvline(x=brady_x, ls="--", lw=2, alpha=0.6, color=color)
@@ -842,7 +842,7 @@ class CFT(BaseProtocol):
             xmax=cft_times["cft_end"],
             ls="--",
             lw=2,
-            color=colors.fau_color(color_key),
+            color=getattr(colors_all, color_key),
             alpha=0.6,
         )
 
@@ -867,7 +867,7 @@ class CFT(BaseProtocol):
             xmax=cft_end,
             ls="--",
             lw=2,
-            color=colors.adjust_color(color_key),
+            color=getattr(colors_all, color_key),
             alpha=0.6,
         )
 
@@ -884,7 +884,7 @@ class CFT(BaseProtocol):
             arrowprops=dict(
                 arrowstyle="<->",
                 lw=2,
-                color=colors.adjust_color(color_key, 1.5),
+                color=getattr(colors_all, f"{color_key}_dark"),
                 shrinkA=0.0,
                 shrinkB=0.0,
             ),
@@ -911,7 +911,7 @@ class CFT(BaseProtocol):
     ) -> None:
 
         color_key = "med"
-        color = colors.fau_color(color_key)
+        color = getattr(colors_all, color_key)
 
         if isinstance(data.index, pd.DatetimeIndex):
             onset_idx = cft_params["onset"]
@@ -969,7 +969,7 @@ class CFT(BaseProtocol):
         color_key = "phil"
         df_cft = self.extract_cft_interval(data)
         if isinstance(df_cft.index, pd.DatetimeIndex):
-            x_poly = df_cft.index.astype(int) / 1e9
+            x_poly = df_cft.index.view(np.int64) / 1e9
         else:
             x_poly = df_cft.index
 
@@ -982,7 +982,7 @@ class CFT(BaseProtocol):
             df_cft.index,
             y_poly,
             lw=2,
-            color=colors.fau_color(color_key),
+            color=getattr(colors_all, color_key),
             alpha=0.6,
             zorder=2,
         )
